# Version file autogenerated by the build process
version = '0.11.3-beta3'
build = 1148
vcs_info = 'Git SHA1 10d9ee8b committed on 2023-05-17'
package_name = 'ksconf'

if __name__ == '__main__':
    print('KSCONF_VERSION="0.11.3-beta3"\nKSCONF_BUILD="1148"\nKSCONF_VCS_INFO="Git SHA1 10d9ee8b committed on 2023-05-17"')
